summaryrefslogtreecommitdiff
path: root/src/lib/subrip_decoder.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2015-11-20 00:33:35 +0000
committerCarl Hetherington <cth@carlh.net>2015-11-20 00:33:35 +0000
commitba48b2755a20fae63c9ae7c89134637ca1a9df3c (patch)
tree52dde4c7bb80b7a25ba560144570258505067821 /src/lib/subrip_decoder.cc
parente9edb9ffd2deee65b2ab044a4a8bc149ed44a0b4 (diff)
Tweak SubRip subtitle default position.
Diffstat (limited to 'src/lib/subrip_decoder.cc')
-rw-r--r--src/lib/subrip_decoder.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/subrip_decoder.cc b/src/lib/subrip_decoder.cc
index a9065994b..2f8b8a5f3 100644
--- a/src/lib/subrip_decoder.cc
+++ b/src/lib/subrip_decoder.cc
@@ -87,10 +87,10 @@ SubRipDecoder::pass (PassReason, bool)
dcp::Time (_subtitles[_next].to.all_as_seconds(), 1000),
0,
dcp::HALIGN_CENTER,
- /* This 0.95 is an arbitrary value to lift the bottom sub off the bottom
- of the screen a bit.
+ /* This 1.015 is an arbitrary value to lift the bottom sub off the bottom
+ of the screen a bit to a pleasing degree.
*/
- 0.95 - ((1 + highest - i.vertical_position.line.get()) * 1.5 / 22),
+ 1.015 - ((1 + highest - i.vertical_position.line.get()) * 1.5 / 22),
dcp::VALIGN_TOP,
j.text,
content->outline() ? dcp::BORDER : dcp::NONE,